@@ -170,9 +170,9 @@ public abstract class Encoding implements Cloneable {
      *
      * @return
      *  0               Never
-     *  > 0             Valid character, length returned
+     *  &gt; 0             Valid character, length returned
      *  -1              Illegal/malformed character
-     *  < -1 (-1 - n)   Number of missing bytes for character in p...end range
+     *  &lt; -1 (-1 - n)   Number of missing bytes for character in p...end range
      *
      * Oniguruma equivalent: <code>mbc_enc_len</code>
      * modified for 1.9 purposes,
@@ -189,6 +189,7 @@ public abstract class Encoding implements Cloneable {
     }
 
     /* ONIGENC_MBC_MAXLEN_DIST */
+    @Deprecated
     public final int maxLengthDistance() {
         return maxLength();
     }
@@ -312,6 +313,12 @@ public abstract class Encoding implements Cloneable {
      */
     public abstract boolean isReverseMatchAllowed(byte[]bytes, int p, int end);
 
+    /**
+     *
+     * Oniguruma equivalent: <code>case_map</code>
+     */
+    public abstract int caseMap(IntHolder flagP, byte[]bytes, IntHolder pp, int end, byte[]to, int toP, int toEnd);
+
     /* onigenc_get_right_adjust_char_head / ONIGENC_LEFT_ADJUST_CHAR_HEAD */
     public final int rightAdjustCharHead(byte[]bytes, int p, int s, int end) {
         int p_ = leftAdjustCharHead(bytes, p, s, end);
@@ -541,6 +548,7 @@ public abstract class Encoding implements Cloneable {
                ctype == CharacterType.PRINT;
     }
 
+    @Deprecated
     public final int mbcodeStartPosition() {
         return minLength() > 1 ? 0 : 0x80;
     }
@@ -556,7 +564,7 @@ public abstract class Encoding implements Cloneable {
     public static final byte NEW_LINE = (byte)0x0a;
 
     public static Encoding load(String name) {
-        String encClassName = "org.jcodings.specific." + name + "Encoding";
+        String encClassName = name;
         Class<?> encClass;
         try {
             encClass = Class.forName(encClassName);
