@@ -21,7 +21,6 @@ package org.jcodings.unicode;
 
 import java.io.DataInputStream;
 import java.io.IOException;
-import java.util.ArrayList;
 
 import org.jcodings.ApplyAllCaseFoldFunction;
 import org.jcodings.CaseFoldCodeItem;
@@ -31,17 +30,15 @@ import org.jcodings.IntHolder;
 import org.jcodings.MultiByteEncoding;
 import org.jcodings.constants.CharacterType;
 import org.jcodings.exception.CharacterPropertyException;
+import org.jcodings.exception.EncodingError;
 import org.jcodings.exception.ErrorMessages;
 import org.jcodings.util.ArrayReader;
 import org.jcodings.util.CaseInsensitiveBytesHash;
 import org.jcodings.util.IntArrayHash;
 import org.jcodings.util.IntHash;
 
-
 public abstract class UnicodeEncoding extends MultiByteEncoding {
-
-    private static final int MAX_WORD_LENGTH = Config.USE_UNICODE_PROPERTIES ? 44 : 6;
-    private static final int PROPERTY_NAME_MAX_SIZE = MAX_WORD_LENGTH + 1;
+    private static final int PROPERTY_NAME_MAX_SIZE = UnicodeProperties.MAX_WORD_LENGTH + 1;
     static final int I_WITH_DOT_ABOVE = 0x0130;
     static final int DOTLESS_i = 0x0131;
     static final int DOT_ABOVE = 0x0307;
@@ -93,13 +90,13 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
         for(int p_ = p; p_ < end; p_+= length(name, p_, end)) {
             int code = mbcToCode(name, p_, end);
             if (code == ' ' || code == '-' || code == '_') continue;
-            if (code >= 0x80) throw new CharacterPropertyException(ErrorMessages.ERR_INVALID_CHAR_PROPERTY_NAME);
+            if (code >= 0x80) throw new CharacterPropertyException(EncodingError.ERR_INVALID_CHAR_PROPERTY_NAME, name, p, end);
             buf[len++] = (byte)code;
-            if (len >= PROPERTY_NAME_MAX_SIZE) throw new CharacterPropertyException(ErrorMessages.ERR_INVALID_CHAR_PROPERTY_NAME, name, p, end);
+            if (len >= PROPERTY_NAME_MAX_SIZE) throw new CharacterPropertyException(EncodingError.ERR_INVALID_CHAR_PROPERTY_NAME, name, p, end);
         }
 
-        Integer ctype = CTypeName.CTypeNameHash.get(buf, 0, len);
-        if (ctype == null) throw new CharacterPropertyException(ErrorMessages.ERR_INVALID_CHAR_PROPERTY_NAME, name, p, end);
+        Integer ctype = CTypeName.Values.get(buf, 0, len);
+        if (ctype == null) throw new CharacterPropertyException(EncodingError.ERR_INVALID_CHAR_PROPERTY_NAME, name, p, end);
         return ctype;
     }
 
@@ -123,7 +120,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
             }
         }
 
-        CodeList to = CaseFold.Hash.get(code);
+        CodeList to = CaseFold.Values.get(code);
         if (to != null) {
             if (to.codes.length == 1) {
                 return codeToMbc(to.codes[0], fold, foldP);
@@ -275,7 +272,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
 
         int n = 0;
         int fn = 0;
-        CodeList to = CaseFold.Hash.get(code);
+        CodeList to = CaseFold.Values.get(code);
         CaseFoldCodeItem[]items = null;
         if (to != null) {
             items = new CaseFoldCodeItem[Config.ENC_GET_CASE_FOLD_CODES_MAX_NUM];
@@ -287,7 +284,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
                 n++;
 
                 code = to.codes[0];
-                to = CaseUnfold11.Hash.get(code);
+                to = CaseUnfold11.Values.get(code);
 
                 if (to != null) {
                     for (int i=0; i<to.codes.length; i++) {
@@ -303,7 +300,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
 
                 for (fn=0; fn<to.codes.length; fn++) {
                     cs[fn][0] = to.codes[fn];
-                    CodeList z3 = CaseUnfold11.Hash.get(cs[fn][0]);
+                    CodeList z3 = CaseUnfold11.Values.get(cs[fn][0]);
                     if (z3 != null) {
                         for (int i=0; i<z3.codes.length; i++) {
                             cs[fn][i+1] = z3.codes[i];
@@ -322,7 +319,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
                         }
                     }
 
-                    CodeList z2 = CaseUnfold12.Hash.get(to.codes);
+                    CodeList z2 = CaseUnfold12.Values.get(to.codes);
                     if (z2 != null) {
                         for (int i=0; i<z2.codes.length; i++) {
                             if (z2.codes[i] == code) continue;
@@ -339,7 +336,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
                             }
                         }
                     }
-                    CodeList z2 = CaseUnfold13.Hash.get(to.codes);
+                    CodeList z2 = CaseUnfold13.Values.get(to.codes);
                     if (z2 != null) {
                         for (int i=0; i<z2.codes.length; i++) {
                             if (z2.codes[i] == code) continue;
@@ -352,7 +349,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
                 flag = 0; /* DISABLE_CASE_FOLD_MULTI_CHAR(flag); */
             }
         } else {
-            to = CaseUnfold11.Hash.get(code);
+            to = CaseUnfold11.Values.get(code);
             if (to != null) {
                 items = new CaseFoldCodeItem[Config.ENC_GET_CASE_FOLD_CODES_MAX_NUM];
                 for (int i=0; i<to.codes.length; i++) {
@@ -370,7 +367,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
                 final int codes0 = code;
                 final int codes1;
                 code = mbcToCode(bytes, p, end);
-                to = CaseFold.Hash.get(code);
+                to = CaseFold.Values.get(code);
                 if (to != null && to.codes.length == 1) {
                     codes1 = to.codes[0];
                 } else {
@@ -379,7 +376,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
 
                 int clen = length(bytes, p, end);
                 len += clen;
-                CodeList z2 = CaseUnfold12.Hash.get(codes0, codes1);
+                CodeList z2 = CaseUnfold12.Values.get(codes0, codes1);
                 if (z2 != null) {
                     for (int i=0; i<z2.codes.length; i++) {
                         items[n] = CaseFoldCodeItem.create(len, z2.codes[i]);
@@ -391,7 +388,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
                 if (p < end) {
                     final int codes2;
                     code = mbcToCode(bytes, p, end);
-                    to = CaseFold.Hash.get(code);
+                    to = CaseFold.Values.get(code);
                     if (to != null && to.codes.length == 1) {
                         codes2 = to.codes[0];
                     } else {
@@ -399,7 +396,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
                     }
                     clen = length(bytes, p, end);
                     len += clen;
-                    z2 = CaseUnfold13.Hash.get(codes0, codes1, codes2);
+                    z2 = CaseUnfold13.Values.get(codes0, codes1, codes2);
                     if (z2 != null) {
                         for (int i=0; i<z2.codes.length; i++) {
                             items[n] = CaseFoldCodeItem.create(len, z2.codes[i]);
@@ -410,7 +407,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
             }
         }
 
-        if (items == null || n == 0) return EMPTY_FOLD_CODES;
+        if (items == null || n == 0) return CaseFoldCodeItem.EMPTY_FOLD_CODES;
         if (n < items.length) {
             CaseFoldCodeItem [] tmp = new CaseFoldCodeItem[n];
             System.arraycopy(items, 0, tmp, 0, n);
@@ -464,50 +461,58 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
                         flags |= Config.CASE_MODIFIED;
                         code = 'I';
                     }
-                } else if ((folded = CaseFold.Hash.get(code)) != null) {
+                } else if ((folded = CaseFold.Values.get(code)) != null) {
                     if ((flags & Config.CASE_TITLECASE) != 0 && (folded.flags & Config.CASE_IS_TITLECASE) != 0) {
 
                     } else if ((flags & folded.flags) != 0) {
-                        int[]codes;
+                        final int[]codes;
+                        final int start;
+                        final int finish;
                         boolean specialCopy = false;
                         flags |= Config.CASE_MODIFIED;
                         if ((flags & folded.flags & Config.CASE_SPECIALS) != 0) {
+                            codes = CaseMappingSpecials.Values;
                             int specialStart = (folded.flags & Config.SpecialIndexMask) >>> Config.SpecialIndexShift;
                             if ((folded.flags & Config.CASE_IS_TITLECASE) != 0) {
                                 if ((flags & (Config.CASE_UPCASE | Config.CASE_DOWNCASE)) == (Config.CASE_UPCASE | Config.CASE_DOWNCASE))
                                     specialCopy = true;
                                 else
-                                    specialStart++;
+                                    specialStart += extractLength(codes[specialStart]);
                             }
                             if (!specialCopy && (folded.flags & Config.CASE_TITLECASE) != 0) {
                                 if ((flags & Config.CASE_TITLECASE) != 0)
                                     specialCopy = true;
                                 else
-                                    specialStart++;
+                                    specialStart += extractLength(codes[specialStart]);
                             }
                             if (!specialCopy && (folded.flags & Config.CASE_DOWN_SPECIAL) != 0) {
                                 if ((flags & Config.CASE_DOWN_SPECIAL) == 0)
-                                    specialStart++;
+                                    specialStart += extractLength(codes[specialStart]);
                             }
-                            codes = CaseMappingSpecials.Values.get(specialStart);
+                            start = specialStart;
+                            finish = start + extractLength(codes[specialStart]);
+                            code =  extractCode(codes[specialStart]);
                         } else {
                             codes = folded.codes;
+                            start = 0;
+                            finish = folded.codes.length;
+                            code = codes[0];
                         }
-                        code = codes[0];
 
-                        for (int i = 1; i < codes.length; i++) {
+                        for (int i = start + 1; i < finish; i++) {
                             toP += codeToMbc(code, to, toP);
                             code = codes[i];
                         }
                     }
-                } else if ((folded = CaseUnfold11.Hash.get(code)) != null && (flags & folded.flags) != 0) {
+                } else if ((folded = CaseUnfold11.Values.get(code)) != null && (flags & folded.flags) != 0) {
                     flags |= Config.CASE_MODIFIED;
                     code = folded.codes[(flags & folded.flags & Config.CASE_TITLECASE) != 0 ? 1 : 0];
                 }
             }
             toP += codeToMbc(code, to, toP);
             if ((flags & Config.CASE_TITLECASE) != 0) {
-                flags ^= (Config.CASE_UPCASE | Config.CASE_DOWNCASE | Config.CASE_TITLECASE | Config.CASE_UP_SPECIAL | Config.CASE_DOWN_SPECIAL);}
+                flags ^= (Config.CASE_UPCASE | Config.CASE_DOWNCASE | Config.CASE_TITLECASE | Config.CASE_UP_SPECIAL | Config.CASE_DOWN_SPECIAL);
+            }
 
         } // while
         flagP.value = flags;
@@ -565,7 +570,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
     }
 
     static class CTypeName {
-        private static final CaseInsensitiveBytesHash<Integer> CTypeNameHash = initializeCTypeNameTable();
+        private static final CaseInsensitiveBytesHash<Integer> Values = initializeCTypeNameTable();
 
         private static CaseInsensitiveBytesHash<Integer> initializeCTypeNameTable() {
             CaseInsensitiveBytesHash<Integer> table = new CaseInsensitiveBytesHash<Integer>();
@@ -606,7 +611,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
             }
         }
 
-        static final IntHash<CodeList>Hash = read("CaseFold");
+        static final IntHash<CodeList>Values = read("CaseFold");
     }
 
     private static class CaseUnfold11 {
@@ -652,7 +657,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
             }
             return hash;
         }
-        static final IntHash<CodeList> Hash = initializeUnfold1Hash();
+        static final IntHash<CodeList> Values = initializeUnfold1Hash();
     }
 
     private static Object[] readFoldN(int fromSize, String table) {
@@ -702,7 +707,7 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
             return unfold2;
         }
 
-        static final IntArrayHash<CodeList> Hash = initializeUnfold2Hash();
+        static final IntArrayHash<CodeList> Values = initializeUnfold2Hash();
     }
 
     private static class CaseUnfold13 {
@@ -724,33 +729,18 @@ public abstract class UnicodeEncoding extends MultiByteEncoding {
             return unfold3;
         }
 
-        static final IntArrayHash<CodeList> Hash = initializeUnfold3Hash();
+        static final IntArrayHash<CodeList> Values = initializeUnfold3Hash();
+    }
+
+    private static int extractLength(int packed) {
+        return packed >>> Config.SpecialsLengthOffset;
+    }
+
+    private static int extractCode(int packed) {
+        return packed & ((1 << Config.SpecialsLengthOffset) - 1);
     }
 
     private static class CaseMappingSpecials {
-        static ArrayList<int[]> read() {
-            try {
-                DataInputStream dis = ArrayReader.openStream("CaseMappingSpecials");
-                int size = dis.readInt();
-                ArrayList<int[]> values = new ArrayList<int[]>(size);
-                for (int i = 0; i < size; i++) {
-                    int packed = dis.readInt();
-                    int length = packed >>> Config.SpecialsLengthOffset;
-                    int[]codes = new int[length];
-                    codes[0] = packed & ((1 << Config.SpecialsLengthOffset) - 1);
-                    for (int j = 1; j < length; j++) {
-                        i++;
-                        codes[j] = dis.readInt();
-                    }
-                    values.add(codes);
-                }
-                dis.close();
-                return values;
-            } catch (IOException ioe) {
-                throw new RuntimeException(ioe);
-            }
-        }
-
-        static final ArrayList<int[]> Values = read();
+        static final int[] Values = ArrayReader.readIntArray("CaseMappingSpecials");
     }
 }
