@@ -145,7 +145,8 @@ public class UnicodeProperties {
         new CodeRangeEntry("xidc", "CR_XID_Continue"),
         new CodeRangeEntry("defaultignorablecodepoint", "CR_Default_Ignorable_Code_Point"),
         new CodeRangeEntry("di", "CR_Default_Ignorable_Code_Point"),
-        new CodeRangeEntry("graphemeclusterbreak=extend", "CR_Grapheme_Extend"),
+        new CodeRangeEntry("graphemeextend", "CR_Grapheme_Extend"),
+        new CodeRangeEntry("grext", "CR_Grapheme_Extend"),
         new CodeRangeEntry("graphemebase", "CR_Grapheme_Base"),
         new CodeRangeEntry("grbase", "CR_Grapheme_Base"),
         new CodeRangeEntry("graphemelink", "CR_Grapheme_Link"),
@@ -420,6 +421,20 @@ public class UnicodeProperties {
         new CodeRangeEntry("soyo", "CR_Soyombo"),
         new CodeRangeEntry("zanabazarsquare", "CR_Zanabazar_Square"),
         new CodeRangeEntry("zanb", "CR_Zanabazar_Square"),
+        new CodeRangeEntry("dogra", "CR_Dogra"),
+        new CodeRangeEntry("dogr", "CR_Dogra"),
+        new CodeRangeEntry("gunjalagondi", "CR_Gunjala_Gondi"),
+        new CodeRangeEntry("gong", "CR_Gunjala_Gondi"),
+        new CodeRangeEntry("makasar", "CR_Makasar"),
+        new CodeRangeEntry("maka", "CR_Makasar"),
+        new CodeRangeEntry("medefaidrin", "CR_Medefaidrin"),
+        new CodeRangeEntry("medf", "CR_Medefaidrin"),
+        new CodeRangeEntry("hanifirohingya", "CR_Hanifi_Rohingya"),
+        new CodeRangeEntry("rohg", "CR_Hanifi_Rohingya"),
+        new CodeRangeEntry("sogdian", "CR_Sogdian"),
+        new CodeRangeEntry("sogd", "CR_Sogdian"),
+        new CodeRangeEntry("oldsogdian", "CR_Old_Sogdian"),
+        new CodeRangeEntry("sogo", "CR_Old_Sogdian"),
         new CodeRangeEntry("whitespace", "CR_Space"),
         new CodeRangeEntry("wspace", "CR_Space"),
         new CodeRangeEntry("bidicontrol", "CR_Bidi_Control"),
@@ -486,9 +501,10 @@ public class UnicodeProperties {
         new CodeRangeEntry("graphemeclusterbreak=regionalindicator", "CR_Regional_Indicator"),
         new CodeRangeEntry("emoji", "CR_Emoji"),
         new CodeRangeEntry("emojipresentation", "CR_Emoji_Presentation"),
-        new CodeRangeEntry("graphemeclusterbreak=emodifier", "CR_Emoji_Modifier"),
+        new CodeRangeEntry("emojimodifier", "CR_Emoji_Modifier"),
         new CodeRangeEntry("emojimodifierbase", "CR_Emoji_Modifier_Base"),
         new CodeRangeEntry("emojicomponent", "CR_Emoji_Component"),
+        new CodeRangeEntry("extendedpictographic", "CR_Extended_Pictographic"),
         new CodeRangeEntry("unknown", "CR_Unknown"),
         new CodeRangeEntry("zzzz", "CR_Unknown"),
         new CodeRangeEntry("age=1.1", "CR_Age_1_1"),
@@ -510,12 +526,12 @@ public class UnicodeProperties {
         new CodeRangeEntry("age=8.0", "CR_Age_8_0"),
         new CodeRangeEntry("age=9.0", "CR_Age_9_0"),
         new CodeRangeEntry("age=10.0", "CR_Age_10_0"),
+        new CodeRangeEntry("age=11.0", "CR_Age_11_0"),
         new CodeRangeEntry("graphemeclusterbreak=prepend", "CR_Grapheme_Cluster_Break_Prepend"),
         new CodeRangeEntry("graphemeclusterbreak=cr", "CR_Grapheme_Cluster_Break_CR"),
         new CodeRangeEntry("graphemeclusterbreak=lf", "CR_NEWLINE"),
         new CodeRangeEntry("graphemeclusterbreak=control", "CR_Grapheme_Cluster_Break_Control"),
-        new CodeRangeEntry("graphemeextend", "CR_Grapheme_Extend"),
-        new CodeRangeEntry("grext", "CR_Grapheme_Extend"),
+        new CodeRangeEntry("graphemeclusterbreak=extend", "CR_Grapheme_Cluster_Break_Extend"),
         new CodeRangeEntry("regionalindicator", "CR_Regional_Indicator"),
         new CodeRangeEntry("ri", "CR_Regional_Indicator"),
         new CodeRangeEntry("graphemeclusterbreak=spacingmark", "CR_Grapheme_Cluster_Break_SpacingMark"),
@@ -524,11 +540,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("graphemeclusterbreak=t", "CR_Grapheme_Cluster_Break_T"),
         new CodeRangeEntry("graphemeclusterbreak=lv", "CR_Grapheme_Cluster_Break_LV"),
         new CodeRangeEntry("graphemeclusterbreak=lvt", "CR_Grapheme_Cluster_Break_LVT"),
-        new CodeRangeEntry("graphemeclusterbreak=ebase", "CR_Grapheme_Cluster_Break_E_Base"),
-        new CodeRangeEntry("emojimodifier", "CR_Emoji_Modifier"),
         new CodeRangeEntry("graphemeclusterbreak=zwj", "CR_Grapheme_Cluster_Break_ZWJ"),
-        new CodeRangeEntry("graphemeclusterbreak=glueafterzwj", "CR_Grapheme_Cluster_Break_Glue_After_Zwj"),
-        new CodeRangeEntry("graphemeclusterbreak=ebasegaz", "CR_Grapheme_Cluster_Break_E_Base_GAZ"),
         new CodeRangeEntry("inbasiclatin", "CR_ASCII"),
         new CodeRangeEntry("inlatin1supplement", "CR_In_Latin_1_Supplement"),
         new CodeRangeEntry("inlatinextendeda", "CR_In_Latin_Extended_A"),
@@ -593,6 +605,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("olchiki", "CR_Ol_Chiki"),
         new CodeRangeEntry("olck", "CR_Ol_Chiki"),
         new CodeRangeEntry("incyrillicextendedc", "CR_In_Cyrillic_Extended_C"),
+        new CodeRangeEntry("ingeorgianextended", "CR_In_Georgian_Extended"),
         new CodeRangeEntry("insundanesesupplement", "CR_In_Sundanese_Supplement"),
         new CodeRangeEntry("invedicextensions", "CR_In_Vedic_Extensions"),
         new CodeRangeEntry("inphoneticextensions", "CR_In_Phonetic_Extensions"),
@@ -739,7 +752,10 @@ public class UnicodeProperties {
         new CodeRangeEntry("inpsalterpahlavi", "CR_In_Psalter_Pahlavi"),
         new CodeRangeEntry("inoldturkic", "CR_In_Old_Turkic"),
         new CodeRangeEntry("inoldhungarian", "CR_In_Old_Hungarian"),
+        new CodeRangeEntry("inhanifirohingya", "CR_In_Hanifi_Rohingya"),
         new CodeRangeEntry("inruminumeralsymbols", "CR_In_Rumi_Numeral_Symbols"),
+        new CodeRangeEntry("inoldsogdian", "CR_In_Old_Sogdian"),
+        new CodeRangeEntry("insogdian", "CR_In_Sogdian"),
         new CodeRangeEntry("inbrahmi", "CR_In_Brahmi"),
         new CodeRangeEntry("inkaithi", "CR_In_Kaithi"),
         new CodeRangeEntry("insorasompeng", "CR_In_Sora_Sompeng"),
@@ -758,6 +774,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("inmongoliansupplement", "CR_In_Mongolian_Supplement"),
         new CodeRangeEntry("intakri", "CR_In_Takri"),
         new CodeRangeEntry("inahom", "CR_In_Ahom"),
+        new CodeRangeEntry("indogra", "CR_In_Dogra"),
         new CodeRangeEntry("inwarangciti", "CR_In_Warang_Citi"),
         new CodeRangeEntry("inzanabazarsquare", "CR_In_Zanabazar_Square"),
         new CodeRangeEntry("insoyombo", "CR_In_Soyombo"),
@@ -765,6 +782,8 @@ public class UnicodeProperties {
         new CodeRangeEntry("inbhaiksuki", "CR_In_Bhaiksuki"),
         new CodeRangeEntry("inmarchen", "CR_In_Marchen"),
         new CodeRangeEntry("inmasaramgondi", "CR_In_Masaram_Gondi"),
+        new CodeRangeEntry("ingunjalagondi", "CR_In_Gunjala_Gondi"),
+        new CodeRangeEntry("inmakasar", "CR_In_Makasar"),
         new CodeRangeEntry("incuneiform", "CR_In_Cuneiform"),
         new CodeRangeEntry("incuneiformnumbersandpunctuation", "CR_In_Cuneiform_Numbers_and_Punctuation"),
         new CodeRangeEntry("inearlydynasticcuneiform", "CR_In_Early_Dynastic_Cuneiform"),
@@ -774,6 +793,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("inmro", "CR_In_Mro"),
         new CodeRangeEntry("inbassavah", "CR_In_Bassa_Vah"),
         new CodeRangeEntry("inpahawhhmong", "CR_In_Pahawh_Hmong"),
+        new CodeRangeEntry("inmedefaidrin", "CR_In_Medefaidrin"),
         new CodeRangeEntry("inmiao", "CR_In_Miao"),
         new CodeRangeEntry("inideographicsymbolsandpunctuation", "CR_In_Ideographic_Symbols_and_Punctuation"),
         new CodeRangeEntry("intangut", "CR_In_Tangut"),
@@ -786,6 +806,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("inbyzantinemusicalsymbols", "CR_In_Byzantine_Musical_Symbols"),
         new CodeRangeEntry("inmusicalsymbols", "CR_In_Musical_Symbols"),
         new CodeRangeEntry("inancientgreekmusicalnotation", "CR_In_Ancient_Greek_Musical_Notation"),
+        new CodeRangeEntry("inmayannumerals", "CR_In_Mayan_Numerals"),
         new CodeRangeEntry("intaixuanjingsymbols", "CR_In_Tai_Xuan_Jing_Symbols"),
         new CodeRangeEntry("incountingrodnumerals", "CR_In_Counting_Rod_Numerals"),
         new CodeRangeEntry("inmathematicalalphanumericsymbols", "CR_In_Mathematical_Alphanumeric_Symbols"),
@@ -793,6 +814,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("inglagoliticsupplement", "CR_In_Glagolitic_Supplement"),
         new CodeRangeEntry("inmendekikakui", "CR_In_Mende_Kikakui"),
         new CodeRangeEntry("inadlam", "CR_In_Adlam"),
+        new CodeRangeEntry("inindicsiyaqnumbers", "CR_In_Indic_Siyaq_Numbers"),
         new CodeRangeEntry("inarabicmathematicalalphabeticsymbols", "CR_In_Arabic_Mathematical_Alphabetic_Symbols"),
         new CodeRangeEntry("inmahjongtiles", "CR_In_Mahjong_Tiles"),
         new CodeRangeEntry("indominotiles", "CR_In_Domino_Tiles"),
@@ -807,6 +829,7 @@ public class UnicodeProperties {
         new CodeRangeEntry("ingeometricshapesextended", "CR_In_Geometric_Shapes_Extended"),
         new CodeRangeEntry("insupplementalarrowsc", "CR_In_Supplemental_Arrows_C"),
         new CodeRangeEntry("insupplementalsymbolsandpictographs", "CR_In_Supplemental_Symbols_and_Pictographs"),
+        new CodeRangeEntry("inchesssymbols", "CR_In_Chess_Symbols"),
         new CodeRangeEntry("incjkunifiedideographsextensionb", "CR_In_CJK_Unified_Ideographs_Extension_B"),
         new CodeRangeEntry("incjkunifiedideographsextensionc", "CR_In_CJK_Unified_Ideographs_Extension_C"),
         new CodeRangeEntry("incjkunifiedideographsextensiond", "CR_In_CJK_Unified_Ideographs_Extension_D"),
